pub struct Table {
pub name: String,
pub catalog_name: String,
pub schema_name: String,
pub table_type: TableType,
pub data_source_format: DataSourceFormat,
pub columns: Vec<ColumnInfo>,
pub storage_location: String,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub table_id: String,
}Expand description
A table within a schema
Fields
name: Stringcatalog_name: StringName of parent catalog.
schema_name: StringName of parent schema relative to its parent catalog.
table_type: TableTypedata_source_format: DataSourceFormatcolumns: Vec<ColumnInfo>The array of ColumnInfo definitions of the table’s columns.
storage_location: StringStorage root URL for table (for MANAGED, EXTERNAL tables)
comment: Option<String>User-provided free-form text description.
properties: HashMap<String, String>A map of key-value properties attached to the securable.
created_at: DateTime<Utc>Time at which this table was created, in epoch milliseconds.
updated_at: DateTime<Utc>Time at which this table was last modified, in epoch milliseconds.
table_id: StringUnique identifier for the table.